@@ -1,7 +1,8 @@
-# Copyright 2010-2012 Gentoo Foundation
+# Copyright 2010-2013 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
 
 import io
+import platform
 import signal
 import sys
 import traceback
@@ -10,7 +11,7 @@ import errno
 import fcntl
 import portage
 from portage import os, _unicode_decode
-from portage.dbapi.vartree import _get_syncfs
+from portage.util._ctypes import find_library
 import portage.elog.messages
 from portage.util._async.ForkProcess import ForkProcess
 
@@ -22,7 +23,8 @@ class MergeProcess(ForkProcess):
 
 	__slots__ = ('mycat', 'mypkg', 'settings', 'treetype',
 		'vartree', 'blockers', 'pkgloc', 'infloc', 'myebuild',
-		'mydbapi', 'prev_mtimes', 'unmerge', '_elog_reader_fd', '_elog_reg_id',
+		'mydbapi', 'postinst_failure', 'prev_mtimes', 'unmerge',
+		'_elog_reader_fd', '_elog_reg_id',
 		'_buf', '_elog_keys', '_locked_vdb')
 
 	def _start(self):
@@ -44,13 +46,17 @@ class MergeProcess(ForkProcess):
 		# This caches the libc library lookup in the current
 		# process, so that it's only done once rather than
 		# for each child process.
-		_get_syncfs()
+		if platform.system() == "Linux" and \
+			"merge-sync" in settings.features:
+			find_library("c")
 
 		# Inherit stdin by default, so that the pdb SIGUSR1
 		# handler is usable for the subprocess.
 		if self.fd_pipes is None:
 			self.fd_pipes = {}
-		self.fd_pipes.setdefault(0, sys.stdin.fileno())
+		else:
+			self.fd_pipes = self.fd_pipes.copy()
+		self.fd_pipes.setdefault(0, portage._get_stdin().fileno())
 
 		super(MergeProcess, self)._start()
 
@@ -111,8 +117,20 @@ class MergeProcess(ForkProcess):
 		"""
 
 		elog_reader_fd, elog_writer_fd = os.pipe()
+
 		fcntl.fcntl(elog_reader_fd, fcntl.F_SETFL,
 			fcntl.fcntl(elog_reader_fd, fcntl.F_GETFL) | os.O_NONBLOCK)
+
+		# FD_CLOEXEC is enabled by default in Python >=3.4.
+		if sys.hexversion < 0x3040000:
+			try:
+				fcntl.FD_CLOEXEC
+			except AttributeError:
+				pass
+			else:
+				fcntl.fcntl(elog_reader_fd, fcntl.F_SETFD,
+					fcntl.fcntl(elog_reader_fd, fcntl.F_GETFD) | fcntl.FD_CLOEXEC)
+
 		blockers = None
 		if self.blockers is not None:
 			# Query blockers in the main process, since closing
@@ -162,7 +180,6 @@ class MergeProcess(ForkProcess):
 				self.vartree.dbapi._pkgs_changed = True
 				self.vartree.dbapi._clear_pkg_cache(mylink)
 
-				portage.process.spawned_pids.append(pid)
 				return [pid]
 
 			os.close(elog_reader_fd)
@@ -220,6 +237,8 @@ class MergeProcess(ForkProcess):
 				raise
 			except:
 				traceback.print_exc()
+				# os._exit() skips stderr flush!
+				sys.stderr.flush()
 			finally:
 				os._exit(rval)
 
@@ -232,6 +251,12 @@ class MergeProcess(ForkProcess):
 				# in order to avoid a race condition.
 				os._exit(1)
 
+	def _set_returncode(self, wait_retval):
+		ForkProcess._set_returncode(self, wait_retval)
+		if self.returncode == portage.const.RETURNCODE_POSTINST_FAILURE:
+			self.postinst_failure = True
+			self.returncode = os.EX_OK
+
 	def _unregister(self):
 		"""
 		Unregister from the scheduler and close open files.
